from setuptools import setup

setup(
    name="WJp_bigdata3",
    version="1.0",
    py_modules=["WJp_bigdata3"],
    author="Wjp",
    author_email="2878508824@qq.com",
    description="大数据3Wjp"
    )